import { Key } from "interface-datastore";
import { BaseDatastore, Batch, KeyQuery, Options, Query } from "datastore-core/base";
import type { OssDatastoreOptionsI } from "./interface";
import OSS from "ali-oss";
export { OssLock } from "./lib/ossLock";
export { createOssRepo } from "./lib/create-oss-repo";
/**
 * A datastore backed by the file system, save to aliyun oss.
 *
 * Keys need to be sanitized before use, as they are written
 * to the file system as is.
 */
export declare class OssDatastore extends BaseDatastore {
    constructor(path: string, opts: OssDatastoreOptionsI);
    path: string;
    opts: OssDatastoreOptionsI;
    createIfMissing: boolean;
    ossClient: OSS;
    /**
     * Returns the full key which includes the path to the ipfs store
     */
    _getFullKey(key: Key): string;
    /**
     * Store the given value under the key.
     */
    put(key: Key, val: Uint8Array): Promise<void>;
    /**
     * Read from oss.
     */
    get(key: Key): Promise<Uint8Array>;
    /**
     * Check for the existence of the given key.
     */
    has(key: Key): Promise<boolean>;
    /**
     * Delete the record under the given key.
     */
    delete(key: Key): Promise<void>;
    /**
     * Create a new batch object.
     */
    batch(): Batch;
    /**
     * Recursively fetches all keys from oss
     */
    _listKeys(params: {
        prefix?: string;
        StartAfter?: string;
    }, options?: Options): AsyncGenerator<Key, void, undefined>;
    /**
     *
     */
    _all(q: Query, options: Options): AsyncGenerator<{
        key: Key;
        value: Uint8Array;
    }, void, unknown>;
    /**
     *
     */
    _allKeys(q: KeyQuery, options: Options): AsyncGenerator<Key, void, undefined>;
    /**
     * This will check the oss bucket to ensure access and existence
     */
    open(): Promise<void>;
    close(): Promise<void>;
}
//# sourceMappingURL=index.d.ts.map