import type { LockCloser, RepoLock } from "ipfs-repo";
import type OSS from "ali-oss";
/**
 * Uses an object in an oss bucket as a lock to signal that an IPFS repo is in use.
 * When the object exists, the repo is in use.
 * You would normally use this to make sure multiple IPFS nodes don’t use the same oss bucket as a datastore at the same time.
 */
export declare class OssLock implements RepoLock {
    constructor(ossClient: OSS);
    ossClient: OSS;
    /**
     * Returns the location of the lock file given the path it should be located at
     */
    getLockfilePath(dir: string): string;
    /**
     * Creates the lock. This can be overridden to customize where the lock should be created
     */
    lock(dir: string): Promise<LockCloser>;
    /**
     * Returns a LockCloser, which has a `close` method for removing the lock located at `lockPath`
     */
    getCloser(lockPath: string): LockCloser;
    /**
     * Calls back on whether or not a lock exists.
     */
    locked(dir: string): Promise<boolean>;
}
//# sourceMappingURL=ossLock.d.ts.map